"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var React = require("react");
var moment = require("moment");
var formBinders_1 = require("../../form/formBinders");
var grid_1 = require("./../../layout/grid");
var form_1 = require("../form");
var DateInput = (function (_super) {
    __extends(DateInput, _super);
    function DateInput() {
        _super.call(this);
        this.cId = "di_" + Math.random();
        this.state = { day: null, month: null, year: null, date: null };
    }
    DateInput.prototype.getDaysArrayByMonth = function () {
        var activeMoment = this.state.date ? moment(this.state.date, "YYYY-MM-DD") : moment();
        if (this.state.month) {
            activeMoment.set("month", this.state.month - 1);
        }
        var daysInMonth = activeMoment.daysInMonth();
        var arrDays = [];
        for (var d = 1; d < daysInMonth + 1; d++) {
            arrDays.push(d.toString());
        }
        return arrDays;
    };
    DateInput.prototype.dayChanged = function (day) {
        var _this = this;
        this.setState({ day: parseInt(day) }, function () {
            _this.buildDate();
        });
    };
    DateInput.prototype.monthChanged = function (month) {
        var _this = this;
        this.setState({ month: parseInt(month) }, function () {
            _this.buildDate();
        });
    };
    DateInput.prototype.yearChanged = function (year) {
        var _this = this;
        this.setState({ year: parseInt(year) }, function () {
            _this.buildDate();
        });
    };
    DateInput.prototype.componentWillMount = function () {
        if (this.props.date) {
            var d = moment(this.props.date);
            this.setState({ day: d.day(), month: d.month(), year: d.year() });
        }
    };
    DateInput.prototype.componentWillReceiveProps = function (newProps) {
        if (newProps.date) {
            if (!this.state.date) {
                var d = moment(newProps.date);
                this.setState({ day: d.day(), month: d.month(), year: d.year(), date: newProps.date });
            }
            else {
                var d = moment(this.state.date);
                var d2 = moment(newProps.date);
                if (!d.isSame(d2)) {
                    this.setState({ day: d2.day(), month: d2.month(), year: d2.year(), date: newProps.date });
                }
            }
        }
        else {
            this.setState({ day: null, month: null, year: null, date: null });
        }
    };
    DateInput.prototype.buildDate = function () {
        var _this = this;
        var d = this.createDate();
        this.setState({ date: d }, function () {
            if (_this.props.onChange && d) {
                _this.props.onChange(_this.state.date);
            }
        });
    };
    DateInput.prototype.createDate = function () {
        var s = this.state;
        var d;
        if (s.day && s.month && s.year) {
            d = moment().set("day", s.day).set("month", s.month - 1).set("year", s.year).format("YYYY-MM-DD");
        }
        return d;
    };
    DateInput.prototype.render = function () {
        var _this = this;
        var dayOptions = [React.createElement("option", {value: "", disabled: true}, "Day")];
        this.getDaysArrayByMonth().forEach(function (d) {
            dayOptions.push(React.createElement("option", {key: _this.cId + "_day_" + d, value: d}, parseInt(d) < 10 ? "0" + d : d.toString()));
        });
        var monthOptions = [React.createElement("option", {value: "", disabled: true}, "Month")];
        for (var i = 0; i < 12; i++) {
            var month = moment().month(i);
            monthOptions.push(React.createElement("option", {key: this.cId + "_month_" + i, value: month.format("M")}, month.format("MMMM")));
        }
        var yearOptions = [React.createElement("option", {value: "", disabled: true}, "Year")];
        for (var i = 0; i < (this.props.yearsFromNow || 110); i++) {
            var year = this.props.futureDates ? moment().add(i, 'years').year() : moment().subtract(i, 'years').year();
            yearOptions.push(React.createElement("option", {key: this.cId + "_year_" + year, value: year.toString()}, year));
        }
        return React.createElement(form_1.Form, {dataBinder: form_1.Form.jsonDataBinder(this.props.date), onDataChanged: function (d) { return _this.props.onChange(d); }}, React.createElement(grid_1.Grid, null, React.createElement(grid_1.Row, null, React.createElement(grid_1.Col, null, React.createElement("select", {onChange: function (e) { return _this.dayChanged(e.target.value); }, value: this.state.day ? this.state.day.toString() : ""}, dayOptions)), React.createElement(grid_1.Col, null, React.createElement("select", {onChange: function (e) { return _this.monthChanged(e.target.value); }, value: this.state.month ? this.state.month.toString() : ""}, monthOptions)), React.createElement(grid_1.Col, null, React.createElement("select", {onChange: function (e) { return _this.yearChanged(e.target.value); }, value: this.state.year ? this.state.year.toString() : ""}, yearOptions)))));
    };
    return DateInput;
}(React.Component));
exports.DateInput = DateInput;
var DateInputFormBinder = (function (_super) {
    __extends(DateInputFormBinder, _super);
    function DateInputFormBinder() {
        _super.apply(this, arguments);
    }
    DateInputFormBinder.customValue = function (dataName) {
        return new DateInputFormBinder(dataName, "date");
    };
    DateInputFormBinder.prototype.handleValueChanged = function (props, dataBinder, notifyChanged) {
        var _this = this;
        props.onChange = function (e) {
            _this.onChanged(dataBinder, e, notifyChanged);
        };
    };
    return DateInputFormBinder;
}(formBinders_1.FormBinderBase));
exports.DateInputFormBinder = DateInputFormBinder;
